import java.time.DayOfWeek;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Locale;

/**
 * GeneralMethods is a class for commen public methods.
 *
 * @author Felix Wöstemeyer
 * @version 1.4
 */
public class GeneralMethods {

    /**
     * The method getDayNumberNew() gets the Number of day in week
     *
     * @param dateString date as String e.g. 12.12.2022
     * @return the Number of day in week
     * @author Madeleine Vigier
     */
    public static String getDayNumberNew(String dateString) {
        //https://stackoverflow.com/questions/8746084/string-to-localdate
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("dd.MM.yyyy");
        formatter = formatter.withLocale(Locale.GERMANY);  // Locale specifies human language for translating, and cultural norms for lowercase/uppercase and abbreviations and such. Example: Locale.US or Locale.CANADA_FRENCH
        LocalDate date = LocalDate.parse(dateString, formatter);

        DayOfWeek day = date.getDayOfWeek();
        return getDayName(day.getValue());
    }

    /**
     * The method getDayName() gets the weekday
     *
     * @param dayNumber dayNumber e.g. 1 for Monday
     * @return String weekday
     * @author Madeleine Vigier
     */
    public static String getDayName(int dayNumber) {
        if (dayNumber == 1) {
            return "Montag";
        }
        if (dayNumber == 2) {
            return "Dienstag";
        }
        if (dayNumber == 3) {
            return "Mittwoch";
        }
        if (dayNumber == 4) {
            return "Donnerstag";
        }
        if (dayNumber == 5) {
            return "Freitag";
        }

        return null;
    }

}
